<?php

namespace Elemailer\App\Emails;

defined('ABSPATH') || exit;

use \Elemailer\App\Lists\Action as Lists_Action;

/**
 * global emails related base class for initialization
 * 
 * @author elEmailer
 * @since 1.0.0
 */
class Base
{

    use \Elemailer\Traits\Singleton;

    public $emails;
    public $taxonomy;
    public $api;

    /**
     * initialization function for all of the emails related functionality
     *
     * @return void
     * @since 1.0.0
     */
    public function init()
    {
        $this->emails = new Cpt();
        $this->taxonomy = new Taxonomy();
        $this->taxonomy->add_default_terms_for_emails();
        $this->api = new Api();

        // run some action upon post create, save, update from backend of wp 
        add_action( 'save_post_em-emails-template', [$this, 'on_publish_action_from_backend'],10,3);

    }

    /**
     * call page markup for emails functionality function
     *
     * @return void
     * @since 1.0.0
     */
    public function emails_user_interface()
    {
        $option_lists = Lists_Action::instance()->format_lists_for_option();
        $capabilities = array_reverse(Action::instance()->get_all_capabilities());
        if(\Elemailer\Lib\License\Action::instance()->is_plugin_activate()){
            include 'view/emails.php';
        }
    }

    /**
     * Set default template to our Elemailer CPT
     * @since 4.1.1
     */

    public function on_publish_action_from_backend($post_id, $post, $old_status){

        if(wp_is_post_autosave($post_id) || wp_is_post_revision($post_id)) {
            return;
        } //If this is just an autosave or post revision, don't do anything

        if (  did_action( 'elementor/loaded' ) ) {

            update_post_meta($post_id, '_wp_page_template', 'elementor_canvas');
            
            // setting a default email type so the user's template is not lost if user is clever to use keyboard to bypass js check
            if($old_status !='draft') return;
            $currentCat = get_the_terms($post_id,'email_type' ); //Get the current set Category
            
            if( empty( $currentCat ) ) { //Check if category is set
               wp_set_object_terms($post_id, array('Newsletter'), 'email_type', true); 
            }

        }
    }
}
